@@ -44,6 +44,11 @@ def handle_item(config: dict, item: str, data: dict, used_textures: set|None = N
 		content = {}
 		if data.get(OVERRIDE_MODEL):
 			content = data[OVERRIDE_MODEL]
+			if on_off:	# Check if the override model has the on/off texture
+				for key, texture in content["textures"].items():
+					on_off_path = "/".join(texture.split("/")[1:]) + on_off + ".png"
+					if on_off_path in config["textures_files"]:
+						content["textures"][key] = texture + on_off
 
 		else:
 			# If it's a block
@@ -115,6 +120,8 @@ def handle_item(config: dict, item: str, data: dict, used_textures: set|None = N
 				source = f"{config['textures_folder']}/{texture_path}.png"
 				destination = f"{dest_base_textu}/{texture_path}.png"
 				super_copy(source, destination)
+				if os.path.exists(source + ".mcmeta"):
+					super_copy(source + ".mcmeta", destination + ".mcmeta")
 			
 		# Write content
 		write_to_file(f"{dest_base_model}/{item}{on_off}.json", super_json_dump(content, max_level = 4))
